<p align="center">
	<img src="https://raw.githubusercontent.com/nadavyayon/TissueTag/main/tissueTag_logo.png?token=GHSAT0AAAAAACEBVMPN554AA2TCXSAP6JLSZFACQRQ" width="300" >
</p>

# Tissue Tag jupyter image annotator
??? What does it do, small intro ???


## Installation

1) You need to install either [jupyter-lab](https://jupyter.org/install) or [jupyter-notebook](https://jupyter.org/install)
2) Install TissueTag using pip:
```
pip install tissue-tag
```

## General instructions and examples:

1) 
3) When running on farm, you need to set the port (e.g., 5011) you are using to get it plot properly in the correct place 


## How to cite:





